"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withAuth = withAuth;

var _server = require("next/server");

var _jwt = require("../jwt");

function withAuth(options) {
  var _options$secret;

  const secret = (_options$secret = options === null || options === void 0 ? void 0 : options.secret) !== null && _options$secret !== void 0 ? _options$secret : process.env.NEXTAUTH_SECRET;
  return async function middleware(req) {
    var _options$pages, _options$authorized, _pages$signIn;

    const pages = (_options$pages = options === null || options === void 0 ? void 0 : options.pages) !== null && _options$pages !== void 0 ? _options$pages : {};
    const {
      pathname
    } = req.nextUrl;

    if (pathname === pages.signIn || pathname === pages.error) {
      return;
    }

    if (!secret) {
      var _options$pages$error, _options$pages2;

      const code = "NO_SECRET";
      console.error(`[next-auth][error][${code}]`, `\nhttps://next-auth.js.org/errors#${code.toLowerCase()}`);
      return _server.NextResponse.redirect((_options$pages$error = options === null || options === void 0 ? void 0 : (_options$pages2 = options.pages) === null || _options$pages2 === void 0 ? void 0 : _options$pages2.error) !== null && _options$pages$error !== void 0 ? _options$pages$error : "/api/auth/error?error=Configuration");
    }

    const token = await (0, _jwt.getToken)({
      req: {
        headers: req.headers,
        cookies: req.cookies
      },
      secret
    });
    const isAuthorized = options !== null && options !== void 0 && options.authorized ? options === null || options === void 0 ? void 0 : (_options$authorized = options.authorized) === null || _options$authorized === void 0 ? void 0 : _options$authorized.call(options, {
      token,
      req
    }) : !!token;
    if (isAuthorized) return;
    return _server.NextResponse.redirect((_pages$signIn = pages.signIn) !== null && _pages$signIn !== void 0 ? _pages$signIn : "/api/auth/signin");
  };
}